Flask-Security
===================

.. image:: https://img.shields.io/travis/mattupstate/flask-security.svg
    :target: https://travis-ci.org/mattupstate/flask-security

.. image:: https://img.shields.io/coveralls/mattupstate/flask-security.svg
    :target: https://coveralls.io/r/mattupstate/flask-security

.. image:: https://img.shields.io/github/tag/mattupstate/flask-security.svg
    :target: https://github.com/mattupstate/flask-security/releases

.. image:: https://img.shields.io/pypi/dm/flask-security.svg
    :target: https://pypi.python.org/pypi/flask-security
    :alt: Downloads

.. image:: https://img.shields.io/github/license/mattupstate/flask-security.svg
    :target: https://github.com/mattupstate/flask-security/blob/master/LICENSE
    :alt: License

It quickly adds security features to your Flask application.

Resources
---------

- `Documentation <https://flask-security.readthedocs.io/>`_
- `Issue Tracker <https://github.com/mattupstate/flask-security/issues>`_
- `Code <https://github.com/mattupstate/flask-security/>`_
